@@ -1,21 +1,8 @@
 /*
-   This file is part of the KDE games lskat program
-   Copyright (c) 2006 Martin Heni <kde@heni-online.de>
+    This file is part of the KDE games lskat program
+    SPDX-FileCopyrightText: 2006 Martin Heni <kde@heni-online.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 
                           Lskat
                           -----
@@ -30,7 +17,7 @@
 // Qt includes
 #include <QHash>
 
-// KDE includes
+// KF includes
 #include <KXmlGuiWindow>
 
 // Local includes
@@ -72,7 +59,7 @@ public:
      */
     ~Mainwindow();
 
-public slots:
+public Q_SLOTS:
     /**
      * A new game is started from the menu.
      */
@@ -189,7 +176,7 @@ protected:
      */
     int themeIdxFromName(const QString &name);
 
-protected slots:
+protected Q_SLOTS:
     /**
      * Set the input type for a given player number.
      * @param no The player number
